==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="et" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Pildid</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Pildi info</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt+Enter</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Põhiinfo</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Üksikasjad</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Ava kaust</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Loobu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Pildifaili ei leitud</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Liik</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Muutmise kuupäev</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Mõõdud</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Faili suurus</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Pildistamise kuupäev</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure program</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure time</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Flash</source>
        <translation>Välk</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Avasuurus</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Fookuskaugus</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Metering mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>White balance</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lens model</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Värviruum</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Mõõdud</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Silt</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scale to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Millimeetrit</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Sentimeetrit</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Pildi seaded</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Pildi seaded</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switcher</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ring</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>dd.MM.yyyy HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Kinnita</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Loobu</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Sisesta uus nimi</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Vali kaust</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Lisa kaust</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Images</source>
        <translation>Pildid</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Seade on eemaldatud</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Seda kausta enam pole olemas</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Arvutamine...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pildi vaatamine</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vaata</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Täisekraan</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eemalda albumist</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Lemmik</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eemalda lemmikutest</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Määra taustapildiks</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näita failihalduris</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Pildi info</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Eelmine</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Järgmine</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Eelmine ekraan</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Järgmine ekraan</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uus ablum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeta ümber</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Abiinfo</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näita otseteid</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Välju täisekraanilt</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Ava</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Palun sisesta uus otsetee</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Otsetee</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Vaata pilti</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Taasta vaikeväärtused</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Vaata</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Täisekraan</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation>Prindi</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eemalda albumist</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Lemmik</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eemalda lemmikutest</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Määra taustapildiks</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näita failihalduris</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Pildi info</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Uus ablum</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeta ümber</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Eelmine</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Paus</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Esita</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Järgmine</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Välju</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slaidi seaded</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Ülemineku efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kestus</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Ülemineku kestus</translation>
    </message>
    <message>
        <source>second</source>
        <translation>sekund</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>nu lemmikud</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Eelmine</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Järgmine</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Suurus</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Mahuta aknasse</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Tagasi</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Piltide haldamine</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>nu lemmikud</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 Suurus</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Mahuta aknasse</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eemalda lemmikutest</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Lemmik</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Ühtegi pildifaili ei leitud</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Ava pilt</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>Pildifaili ei leitud</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Slaidi seaded</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efekt</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Kestus</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Otsetee</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Vaata</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Album</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Uus ablum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Ajatelg</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Lisa albumisse</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Lisa uude albumisse</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Välju täisekraanilt</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Täisekraan</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Prindi</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Eemalda albumist</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Lemmik</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Eemalda lemmikutest</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Määra taustapildiks</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näita failihalduris</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Pildi info</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Ava pilt</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Kõik pildid</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeta ümber</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Joonista</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.9.16.orig.tar.xz: deepin-image-viewer-5.9.16/src/translations/deepin-image-viewer_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="et" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>Pildifaili ei leitud</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Ava pilt</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Pildi vaatamine</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Seaded</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Täisekraan</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Välju täisekraanilt</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Slaidiseanss</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeta ümber</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopeeri</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Kustuta</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Pööra päripäeva</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Pööra vastupäeva</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Määra taustapildiks</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Näita failihalduris</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Pildi info</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Eelmine</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Järgmine</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>Ava</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Abiinfo</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Näita otseteid</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
